================
NSONE Python SDK
================

:Info: A Python SDK for accessing NSONE, the Data Driven DNS platform.
:Author: Shannon Weyrick

.. image:: https://travis-ci.org/nsone/nsone-python.png
        :target: https://travis-ci.org/nsone/nsone-python

Status
======
Initial development, not for production use yet.


Installation
============

(work in progress)

Documentation
=============

http://nsone.net/api/



